==> profile-changer-widget_1.0.3-1.tar.gz: profile-changer-widget-1.0.3/src/settingsdialog.h <==
#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>
#include <QSettings>
#include <QPushButton>
#include <QDBusInterface>

#define PCW_SETTING_HEIGHT "profilechangerwidget/height"
#define PCW_SETTING_HEIGHT_DEFAULT 72
#define PCW_SETTING_WIDTH "profilechangerwidget/width"
#define PCW_SETTING_WIDTH_DEFAULT 72
#define PCW_SETTING_OPACITY "profilechangerwidget/opacity"
#define PCW_SETTING_OPACITY_DEFAULT 70
#define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
#define PCW_SETTING_SHOWNEXTPROFILE_DEFAULT true
#define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
#define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
#define PCW_SETTING_DEBUG "profilechangerwidget/debug"
#define PCW_SETTING_DEBUG_DEFAULT false
#define PCW_APP_USAGE_LIMIT 5
#define PCW_APP_LOGFILE "/opt/profilechangerwidget/profilechangerwidget.log"
#define PCW_APP_DEVEL true
#define PCW_APP_VERSION "1.0.3"

namespace Ui {
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

signals:
    void settingsChanged();

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();
    void checkVersion();

protected:
    void showEvent(QShowEvent* event);

private:
    Ui::SettingsDialog *ui;
    void openBrowser(QString url);
    void showInformation(QString info);
    void showQuestion(QString info);

private slots:
    void accept();
    void showAbout();
    void on_buttonAbout_clicked();
    void on_buttonQa_clicked();
    void on_buttonDonate_clicked();
    void on_buttonBox_accepted();
    void on_buttonBox_rejected();
};

#endif // SETTINGSDIALOG_H

==> profile-changer-widget_1.0.4-1.tar.gz: profile-changer-widget-1.0.4/src/settingsdialog.h <==
#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>
#include <QSettings>
#include <QPushButton>
#include <QDBusInterface>

#define PCW_SETTING_HEIGHT "profilechangerwidget/height"
#define PCW_SETTING_HEIGHT_DEFAULT 72
#define PCW_SETTING_WIDTH "profilechangerwidget/width"
#define PCW_SETTING_WIDTH_DEFAULT 72
#define PCW_SETTING_OPACITY "profilechangerwidget/opacity"
#define PCW_SETTING_OPACITY_DEFAULT 70
#define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
#define PCW_SETTING_SHOWNEXTPROFILE_DEFAULT true
#define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
#define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
#define PCW_SETTING_DEBUG "profilechangerwidget/debug"
#define PCW_SETTING_DEBUG_DEFAULT false
#define PCW_APP_USAGE_LIMIT 5
#define PCW_APP_LOGFILE "/opt/profilechangerwidget/profilechangerwidget.log"
#define PCW_APP_DEVEL false
#define PCW_APP_VERSION "1.0.4"

namespace Ui {
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

signals:
    void settingsChanged();

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();
    void checkVersion();

protected:
    void showEvent(QShowEvent* event);

private:
    Ui::SettingsDialog *ui;
    void openBrowser(QString url);
    void showInformation(QString info);
    void showQuestion(QString info);

private slots:
    void accept();
    void showAbout();
    void on_buttonAbout_clicked();
    void on_buttonQa_clicked();
    void on_buttonDonate_clicked();
    void on_buttonBox_accepted();
    void on_buttonBox_rejected();
};

#endif // SETTINGSDIALOG_H
